# py-manga
## a library for getting information from mangaupdates.com!
note: i am not affiliated with mangaupdates.com

mangaupdates, while offering a great source of information for your favorite manga, does not properly expose an api. it just returns the page html!
this is where py-manga comes in. using beautifulsoup, it parses all the information out of the html, making it way easier to work with.

**to see how the data is organized, see the project wiki**

### Currently Supported
- Series information
- Searching
- Advanced/Genre Searching
